@@ -116,14 +116,14 @@ class Textractor:
             s3_client = (
                 boto3.session.Session(profile_name=self.profile_name).client("s3")
                 if self.profile_name is not None
-                else boto3.session.Session(region=self.region).client("s3")
+                else boto3.session.Session(region_name=self.region_name).client("s3")
             )
             file_obj = s3_client.get_object(Bucket=bucket, Key=key).get("Body").read()
             if filepath.endswith(".pdf"):
                 if IS_PDF2IMAGE_INSTALLED:
                     images = convert_from_bytes(bytearray(file_obj))
                 else:
-                    raise MissingDependencyException("pdf2image is not installed")
+                    raise MissingDependencyException("pdf2image is not installed. If you do not plan on using visualizations you can skip image generation using save_image=False in your function call.")
             else:
                 images = [Image.open(io.BytesIO(bytearray(file_obj)))]
 
@@ -132,7 +132,7 @@ class Textractor:
                 if IS_PDF2IMAGE_INSTALLED:
                     images = convert_from_path(filepath)
                 else:
-                    raise MissingDependencyException("pdf2image is not installed")
+                    raise MissingDependencyException("pdf2image is not installed. If you do not plan on using visualizations you can skip image generation using save_image=False in your function call.")
             else:
                 images = [Image.open(open(filepath, "rb"))]
 
@@ -629,7 +629,8 @@ class Textractor:
         document = response_parser.parse(response)
         document.response = response
         if save_image:
-            document.image = images[0]
+            for page in document.pages:
+                page.image = images[document.pages.index(page)]
         return document
 
     def analyze_expense(
@@ -788,7 +789,6 @@ class Textractor:
                 client_request_token=client_request_token,
                 return_job_id=True,
                 force_async_api=True,
-                call_mode=Textract_Call_Mode.FORCE_ASYNC,
                 boto3_textract_client=self.textract_client,
                 job_done_polling_interval=1,
             )
@@ -814,7 +814,7 @@ class Textractor:
 
         return LazyDocument(
             response["JobId"],
-            TextractAPI.ANALYZE,
+            TextractAPI.EXPENSE,
             textract_client=self.textract_client,
             images=images,
         )
